#include <gint/display.h>
#include <gint/keyboard.h>
#include "draw.h"
#include "shared_define.h"

#define BG_COLOR 0
#define DRAW_OFFSET_Y -24
#define DRAW_OFFSET_X -27

extern image_t img_player; //player texture, 12x12
extern image_t img_solid_0; //solid texture, 16x16
extern image_t img_solid_1; //solid texture, 16x16
extern image_t img_spike; //spike texture, 16x16
extern image_t img_bouncer; //bouncer texture, 16x16
extern image_t img_ice; //ice texture, 16x8
extern image_t img_blue; //blue bloc texture, 16x16
extern image_t img_blue_dot; //off blue bloc texture, 16x16
extern image_t img_red; //red bloc texture, 16x16
extern image_t img_red_dot; //off red bloc texture, 16x16
extern image_t img_exit; //exit texture, 16x16
extern image_t img_water; //water texture, 16x16
extern image_t img_semi_solid; //semi solid texture, 16x16
//animated textures
extern image_t img_elevator1, img_elevator2, img_elevator3, img_elevator4;
extern image_t img_elevator5, img_elevator6, img_elevator7, img_elevator8;
extern image_t img_elevator9, img_elevator10, img_elevator11, img_elevator12;
extern image_t img_elevator13, img_elevator14, img_elevator15, img_elevator16;
const image_t * ani_elevator[16] = {&img_elevator1, &img_elevator2,
	&img_elevator3, &img_elevator4, &img_elevator5, &img_elevator6,
	&img_elevator7, &img_elevator8, &img_elevator9, &img_elevator10,
	&img_elevator11, &img_elevator12, &img_elevator13, &img_elevator14,
	&img_elevator15, &img_elevator16};

void draw_player(int x, int y)
{
	dimage(x + DRAW_OFFSET_X, y + DRAW_OFFSET_Y, &img_player);
}

void draw_level(char level[], unsigned int step, char polarity, int *start_x,
int *start_y)
{
	dclear(BG_COLOR);
	unsigned int i = 0;
	unsigned int x = 0;
	unsigned int y = 0;
	while (i != LEVEL_WIDTH*16)
	{
		switch (level[i])
		{
			case '0':
				dimage(x + DRAW_OFFSET_X, y + DRAW_OFFSET_Y, &img_solid_0);
				break;
			case '1':
				dimage(x + DRAW_OFFSET_X, y + DRAW_OFFSET_Y, &img_solid_1);
				break;
			case 'r':
				if (!polarity) dimage(x + DRAW_OFFSET_X, y + DRAW_OFFSET_Y, &img_red);
				else dimage(x + DRAW_OFFSET_X, y + DRAW_OFFSET_Y, &img_red_dot);
				break;
			case 'b':
				if (polarity) dimage(x + DRAW_OFFSET_X, y + DRAW_OFFSET_Y, &img_blue);
				else dimage(x + DRAW_OFFSET_X, y + DRAW_OFFSET_Y, &img_blue_dot);
				break;
			case 'v':
				dimage(x + DRAW_OFFSET_X, y + DRAW_OFFSET_Y, &img_spike);
				break;
			case '*':
				dimage(x + DRAW_OFFSET_X, y + DRAW_OFFSET_Y, &img_bouncer);
				break;
			case '~':
				dimage(x + DRAW_OFFSET_X, y + DRAW_OFFSET_Y, &img_solid_0);
				dimage(x + DRAW_OFFSET_X, y + DRAW_OFFSET_Y, &img_ice);
				break;
			case '/':
				dimage(x + DRAW_OFFSET_X, y + DRAW_OFFSET_Y, &img_semi_solid);
				break;
			case '^':
				dimage(x + DRAW_OFFSET_X, y + DRAW_OFFSET_Y, ani_elevator[(step/2)%16]);
				break;
			case 'S':
				erase_tile(x, y, level);
				*start_x = x + 2;
				*start_y = y + 4;
				break;
			case 'E':
				dimage(x + DRAW_OFFSET_X, y + DRAW_OFFSET_Y, &img_exit);
				break;
			case 'w': //water
				dimage(x + DRAW_OFFSET_X, y + DRAW_OFFSET_Y, &img_water);
				break;
		}
		x += 16;
		if (x == 16*LEVEL_WIDTH)
		{
			x = 0;
			y += 16;
		}
		i++;
	}
}

void erase_tile(int x, int y, char level[])
{
	x = (int)(x/16);
	y = (int)(y/16);
	level[x + y * LEVEL_WIDTH] = '.';
	x *= 16;
	y *= 16;
}

void draw_timer(unsigned int step)
{
	dprint(0, 0, C_WHITE, C_BLACK, "%u.%02u", step/60, step%60);
}

void just_breathe(unsigned int step)
{
	int x = 0;
	int y = 0;
	int xspd = 1;
	int yspd = 1;
	while (!keydown_any(KEY_MENU, KEY_EXIT, 0))
	{
		dclear(0);
		dtext(x, y, "Thank you for playing", C_WHITE, C_BLACK);
		dprint(x, y + 12, C_WHITE, C_BLACK, "%u.%02u", step/60, step%60);
		dupdate();
		x += xspd;
		y += yspd;
		if (x == 236 || !x) xspd = 0 - xspd;
		if (y == 203 || !y) yspd = 0 - yspd;
		clearevents();
	}
	{
		unsigned char timeout = 50;
		while(timeout)
		{
			timeout--;
			dclear(0);
		}
	}
}
